@@ -21,7 +21,7 @@
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-  Author: David Suffield
+  Author: David Suffield, Yashwant Sahu
 
 \************************************************************************************/
 
@@ -393,7 +393,18 @@ SANE_Status marvell_open(SANE_String_Const device, SANE_Handle *handle)
    hpmud_query_model(session->uri, &ma);
    session->scan_type = ma.scantype;
    session->scansrc = ma.scansrc;
-   session->scancolor= ma.scancolor;      
+   
+   switch (ma.scantype)
+   {
+      case HPMUD_SCANTYPE_MARVELL:
+         session->version = MARVELL_1;		 
+		 break;
+	  case HPMUD_SCANTYPE_MARVELL2:
+         session->version = MARVELL_2;		
+		 break;
+	  default:
+         session->version = MARVELL_1;
+   };
 
    if (hpmud_open_device(session->uri, ma.mfp_mode, &session->dd) != HPMUD_R_OK)
    {
@@ -429,33 +440,17 @@ SANE_Status marvell_open(SANE_String_Const device, SANE_Handle *handle)
 
    /* Set supported Scan Modes and set sane option. */
    i=0;
-   
-   /* Tsunami doesnt support color scan, getting scan color option from the model file.*/
-   if ( session->scancolor == HPMUD_SCANCOLOR_MONO)
-   {
-       session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_LINEART;
-       session->scan_mode_map[i++] = CE_BLACK_AND_WHITE1;
-       session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_GRAY;
-       session->scan_mode_map[i++] = CE_GRAY8;        
-       DBG8("scan color  HPMUD_SCANCOLOR_MONO \n");        
-   }
-   /*  0 value set in the model file, set all the scan color option */
-   else
-   {   
-       session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_LINEART;
-       session->scan_mode_map[i++] = CE_BLACK_AND_WHITE1;
-       session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_GRAY;
-       session->scan_mode_map[i++] = CE_GRAY8;
-       session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_COLOR;
-       session->scan_mode_map[i++] = CE_RGB24;
-       DBG8("scan color  All \n");        
-   }
+   session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_LINEART;
+   session->scan_mode_map[i++] = CE_BLACK_AND_WHITE1;
+   session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_GRAY;
+   session->scan_mode_map[i++] = CE_GRAY8;
+   session->scan_mode_list[i] = SANE_VALUE_SCAN_MODE_COLOR;
+   session->scan_mode_map[i++] = CE_RGB24;
    marvell_control_option(session, MARVELL_OPTION_SCAN_MODE, SANE_ACTION_SET_AUTO, NULL, NULL); /* set default option */
 
 
    /* Determine scan input source. */
    i=0;
-   
    /* Some of the marvell devices supports both flatbed and ADF, No command to get the src types supported */
    /* Getting from the model file */
    if ( session->scansrc == HPMUD_SCANSRC_BOTH)
@@ -479,7 +474,7 @@ SANE_Status marvell_open(SANE_String_Const device, SANE_Handle *handle)
          DBG8("scan src  HPMUD_SCANSRC_FLATBED \n"); 
     }
     /* Values if un specified in the, value is 0,  get ADF state from the printer */   
-  else if (session->bb_is_paper_in_adf(session) == 2) 
+   else if (session->bb_is_paper_in_adf(session) == 2) 
    {
       session->input_source_list[i] = STR_ADF_MODE_FLATBED;
       session->input_source_map[i++] = IS_PLATEN;
@@ -622,7 +617,6 @@ SANE_Status marvell_control_option(SANE_Handle handle, SANE_Int option, SANE_Act
          else
          {  /* Set default. */
             ps->current_scan_mode = ps->scan_mode_map[0];
-            ps->scan_mode_map[i];
             stat = SANE_STATUS_GOOD;
          }
          break;
@@ -837,7 +831,8 @@ SANE_Status marvell_start(SANE_Handle handle)
 //   int tmo=EXCEPTION_TIMEOUT*2;
 
    DBG8("sane_hpaio_start()\n");
-
+   ps->is_user_cancel = 0;
+   
    if (set_extents(ps))
    {
       BUG("invalid extents: tlx=%d brx=%d tly=%d bry=%d minwidth=%d minheight%d maxwidth=%d maxheight=%d\n",
@@ -861,7 +856,6 @@ SANE_Status marvell_start(SANE_Handle handle)
          goto bugout;
       }
    }
-
    /* Start scan and get actual image traits. */
    if (ps->bb_start_scan(ps))
    {
@@ -975,7 +969,15 @@ bugout:
          ipClose(ps->ip_handle);  
          ps->ip_handle = 0;
       } 
-      ps->bb_end_page(ps, stat == SANE_STATUS_IO_ERROR ? 1: 0);
+       //If user has cancelled scan from device
+      if (ps->is_user_cancel)
+      {
+          //Don't do anything. sane_hpaio_cancel() will be invoked automatically
+       }
+       else 
+	   {
+	       ps->bb_end_page(ps, stat == SANE_STATUS_IO_ERROR ? 1: 0);
+	   }
    }
 
    DBG8("-sane_hpaio_read() output=%p bytes_read=%d maxLength=%d status=%d\n", data, *length, maxLength, stat);
@@ -993,7 +995,8 @@ void marvell_cancel(SANE_Handle handle)
     * Sane_cancel is always called at the end of the scan job. Note that on a multiple page scan job 
     * sane_cancel is called only once.
     */
-
+   ps->is_user_cancel = 1 ;
+   
    if (ps->ip_handle)
    {
       ipClose(ps->ip_handle); 
